@@ -108,6 +108,7 @@ class OrchestratorConfig(BaseModel):
     progress: ProgressConfig = Field(default_factory=ProgressConfig)
     buffer: BufferConfig = Field(default_factory=BufferConfig)
     profiling: ProfilingConfig = Field(default_factory=ProfilingConfig)
+    start_method: str = "spawn"
 
     result_queue_config: QueueConfig = Field(default_factory=QueueConfig)
     requeue_queue_config: QueueConfig = Field(default_factory=QueueConfig)
@@ -151,6 +152,7 @@ class OrchestratorBuilder:
         self._requeue_queue_config: Optional[QueueConfig] = None
         self._resources_to_cleanup: list[Any] = []
         self.context = None
+        self._start_method: str = "spawn"
 
     def without_logging(self) -> "OrchestratorBuilder":
         """Disables the default logger."""
@@ -262,6 +264,15 @@ class OrchestratorBuilder:
         self._orchestrator_thread_pool_size = size
         return self
 
+    def with_start_method(self, method: str) -> "OrchestratorBuilder":
+        """Sets the multiprocessing start method (e.g., 'spawn', 'fork')."""
+        if method not in ["spawn", "fork", "forkserver"]:
+            raise ValueError(
+                f"Unsupported start method: '{method}'. Must be one of 'spawn', 'fork', 'forkserver'."
+            )
+        self._start_method = method
+        return self
+
     def with_actions(self, actions: list["TaskDefinition"]) -> "OrchestratorBuilder":
         """Registers task definitions with the orchestrator."""
         self._registered_actions.extend(actions)
@@ -274,6 +285,7 @@ class OrchestratorBuilder:
 
     def from_config(self, config: OrchestratorConfig) -> "OrchestratorBuilder":
         """Configures the builder from an OrchestratorConfig object."""
+        self.with_start_method(config.start_method)
         self.with_progress_bar(config.progress.enabled)
         if config.orchestrator_thread_pool_size is not None:
             self.with_orchestrator_thread_pool_size(
@@ -339,7 +351,7 @@ class OrchestratorBuilder:
         Returns:
             A fully configured `Orchestrator` ready to be started.
         """
-        self.context = get_context("spawn")
+        self.context = get_context(self._start_method)
         context = self.context
         orchestrator_thread_pool_size = self._orchestrator_thread_pool_size or 2
         num_task_workers = sum(
